<?php
/*
Plugin Name: PJW Mime Config 
Plugin URI: http://blog.ftwr.co.uk/wordpress/mime-config/
Description: Allows you to <a href="options-general.php?page=pjw-mime-config">extend the list of mime-types</a> supported by the builtin uploader.
Author: Peter Westwood
Version: 0.5
Author URI: http://blog.ftwr.co.uk/
*/

/*  Copyright 2006  Peter Westwood  (email : peter.westwood@ftwr.co.uk)

    This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation; either version 2 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

class pjw_mime_config
{
	// Some default extras
	var	$mime_types = array ();
	var $default_types = array (
						'ac3' => 'audio/ac3',
						'mpa' => 'audio/MPA',
						'flv' => 'video/x-flv'
						);

	//Constructor
	function pjw_mime_config()
	{
		add_action('admin_menu', array(&$this,'admin_menu'));
		add_filter('upload_mimes',array(&$this,'upload_mimes'));
    	add_option('pjw_mime_types',$this->default_types,'Additional mime-types for the inline uploader.','no');
	}
	
	function admin_menu()
	{
		add_options_page('Mime types','Mime types','manage_options','pjw-mime-config',array(&$this,'display_page'));
	}

	function display_page()
	{
		if (!current_user_can('manage_options'))
		{
			?><div id="message" class="updated fade"><p>Sorry you don't have the privilidges to do this!</p></div><?php
		}
		else 
		{
			//Load them up
			$this->mime_types = get_option('pjw_mime_types');						
			if (isset($_POST["action"]) && "addmime" == $_POST["action"])
			{
				$this->mime_types[$_POST["mime-ext"]] = $_POST["mime-type"];
                update_option('pjw_mime_types',$this->mime_types);
				?><div id="message" class="updated fade"><p><? echo $_GET["mime-ext"]; ?> mime-type added.</p></div><?php
			}
			elseif (isset($_POST["action"]) && "restoremime" == $_POST["action"])
			{
                update_option('pjw_mime_types',$this->default_types);
				$this->mime_types = get_option('pjw_mime_types');						
				?><div id="message" class="updated fade"><p>Restored default mime-types.</p></div><?php
			}
			elseif (isset($_GET["action"]) && "delmime" == $_GET["action"])
			{
				unset($this->mime_types[$_GET["mime-ext"]]);
                update_option('pjw_mime_types',$this->mime_types);
				?><div id="message" class="updated fade"><p><? echo $_GET["mime-ext"]; ?> mime-type deleted.</p></div><?php
			}
		
			?>
		<div class="wrap">
		<h2>Mime-type management</h2>
			<?php
			if (!empty($this->mime_types))
			{
			?>
		<p>The current extra mime-types are registered for use with the inline uploader.</p>
		<table id="mime-types" width="100%" cellpadding="3" cellspacing="3">
		<tr><th scope="col">File extension</th><th scope="col">Mime type</th><th scope="col">Action</th></tr>
			<?php
				foreach($this->mime_types as $ext => $type)
				{
				?>
				<tr class='alternate'>
					<td align='center'><?php echo $ext; ?></td>
					<td align='center'><?php echo $type; ?></td>
					<td align='center'>
						<a href="options-general.php?page=pjw-mime-config&action=delmime&mime-ext=<? echo "$ext";?>" class='delete'>Delete</a>
					</td>
				</tr>
				<?php
				}
			?>
		</table>
			<?php
			}
			else
			{
			?>
		<p>No mime-types are currently registered. If you want you can restore the original set of extra mime-types</p>
		<form name="restoremime" id="restoremime" action="options-general.php?page=pjw-mime-config" method="post">
			<p class="submit"><input type="hidden" name="action" value="restoremime" />
			<input type="submit" name="submit" value="Restore default mime-types &raquo;" /></p>
		</form>
			<?php
			}
			?>
		</div>
		<div class="wrap">
		<h2>Add New mime-type</h2>
		<form name="addmime" id="addmime" action="options-general.php?page=pjw-mime-config" method="post">
			<p>File Extension:
			<input type="text" name="mime-ext" value="" /></p>
			<p>Associated mime-type:
			<input type="text" name="mime-type" value="" /></p>
			<p class="submit"><input type="hidden" name="action" value="addmime" />
			<input type="submit" name="submit" value="Add mime-type &raquo;" /></p>
		</form>
		</div>
			<?php
		}
	}

	//Add in our extra mime-types to the supplied array
	function upload_mimes($mimes)
	{
		$this->mime_types = get_option('pjw_mime_types');						
		return array_merge($mimes,$this->mime_types);
	}
}

/* Initialise outselves */
$pjw_mime_config = new pjw_mime_config;

